# Column/Label Types
NULL = 'null'
CATEGORICAL = 'categorical'
TEXT = 'text'
NUMERICAL = 'numerical'
ENTITY = 'entity'

# Problem Types
REGRESSION = 'regression'
CLASSIFICATION = 'classification'
BINARY = 'binary'
